@@ -6,9 +6,9 @@ Type annotations for cloud9 service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_cloud9.type_defs import CreateEnvironmentEC2RequestTypeDef
+    from mypy_boto3_cloud9.type_defs import CreateEnvironmentEC2RequestRequestTypeDef
 
-    data: CreateEnvironmentEC2RequestTypeDef = {...}
+    data: CreateEnvironmentEC2RequestRequestTypeDef = {...}
     ```
 """
 import sys
@@ -32,44 +32,44 @@ else:
 
 
 __all__ = (
-    "CreateEnvironmentEC2RequestTypeDef",
-    "CreateEnvironmentEC2ResultResponseTypeDef",
-    "CreateEnvironmentMembershipRequestTypeDef",
-    "CreateEnvironmentMembershipResultResponseTypeDef",
-    "DeleteEnvironmentMembershipRequestTypeDef",
-    "DeleteEnvironmentRequestTypeDef",
-    "DescribeEnvironmentMembershipsRequestTypeDef",
-    "DescribeEnvironmentMembershipsResultResponseTypeDef",
-    "DescribeEnvironmentStatusRequestTypeDef",
-    "DescribeEnvironmentStatusResultResponseTypeDef",
-    "DescribeEnvironmentsRequestTypeDef",
-    "DescribeEnvironmentsResultResponseTypeDef",
+    "CreateEnvironmentEC2RequestRequestTypeDef",
+    "CreateEnvironmentEC2ResultTypeDef",
+    "CreateEnvironmentMembershipRequestRequestTypeDef",
+    "CreateEnvironmentMembershipResultTypeDef",
+    "DeleteEnvironmentMembershipRequestRequestTypeDef",
+    "DeleteEnvironmentRequestRequestTypeDef",
+    "DescribeEnvironmentMembershipsRequestRequestTypeDef",
+    "DescribeEnvironmentMembershipsResultTypeDef",
+    "DescribeEnvironmentStatusRequestRequestTypeDef",
+    "DescribeEnvironmentStatusResultTypeDef",
+    "DescribeEnvironmentsRequestRequestTypeDef",
+    "DescribeEnvironmentsResultTypeDef",
     "EnvironmentLifecycleTypeDef",
     "EnvironmentMemberTypeDef",
     "EnvironmentTypeDef",
-    "ListEnvironmentsRequestTypeDef",
-    "ListEnvironmentsResultResponseTypeDef",
-    "ListTagsForResourceRequestTypeDef",
-    "ListTagsForResourceResponseResponseTypeDef",
+    "ListEnvironmentsRequestRequestTypeDef",
+    "ListEnvironmentsResultTypeDef",
+    "ListTagsForResourceRequestRequestTypeDef",
+    "ListTagsForResourceResponseTypeDef",
     "PaginatorConfigTypeDef",
     "ResponseMetadataTypeDef",
-    "TagResourceRequestTypeDef",
+    "TagResourceRequestRequestTypeDef",
     "TagTypeDef",
-    "UntagResourceRequestTypeDef",
-    "UpdateEnvironmentMembershipRequestTypeDef",
-    "UpdateEnvironmentMembershipResultResponseTypeDef",
-    "UpdateEnvironmentRequestTypeDef",
+    "UntagResourceRequestRequestTypeDef",
+    "UpdateEnvironmentMembershipRequestRequestTypeDef",
+    "UpdateEnvironmentMembershipResultTypeDef",
+    "UpdateEnvironmentRequestRequestTypeDef",
 )
 
-_RequiredCreateEnvironmentEC2RequestTypeDef = TypedDict(
-    "_RequiredCreateEnvironmentEC2RequestTypeDef",
+_RequiredCreateEnvironmentEC2RequestRequestTypeDef = TypedDict(
+    "_RequiredCreateEnvironmentEC2RequestRequestTypeDef",
     {
         "name": str,
         "instanceType": str,
     },
 )
-_OptionalCreateEnvironmentEC2RequestTypeDef = TypedDict(
-    "_OptionalCreateEnvironmentEC2RequestTypeDef",
+_OptionalCreateEnvironmentEC2RequestRequestTypeDef = TypedDict(
+    "_OptionalCreateEnvironmentEC2RequestRequestTypeDef",
     {
         "description": str,
         "clientRequestToken": str,
@@ -84,22 +84,23 @@ _OptionalCreateEnvironmentEC2RequestTypeDef = TypedDict(
 )
 
 
-class CreateEnvironmentEC2RequestTypeDef(
-    _RequiredCreateEnvironmentEC2RequestTypeDef, _OptionalCreateEnvironmentEC2RequestTypeDef
+class CreateEnvironmentEC2RequestRequestTypeDef(
+    _RequiredCreateEnvironmentEC2RequestRequestTypeDef,
+    _OptionalCreateEnvironmentEC2RequestRequestTypeDef,
 ):
     pass
 
 
-CreateEnvironmentEC2ResultResponseTypeDef = TypedDict(
-    "CreateEnvironmentEC2ResultResponseTypeDef",
+CreateEnvironmentEC2ResultTypeDef = TypedDict(
+    "CreateEnvironmentEC2ResultTypeDef",
     {
         "environmentId": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-CreateEnvironmentMembershipRequestTypeDef = TypedDict(
-    "CreateEnvironmentMembershipRequestTypeDef",
+CreateEnvironmentMembershipRequestRequestTypeDef = TypedDict(
+    "CreateEnvironmentMembershipRequestRequestTypeDef",
     {
         "environmentId": str,
         "userArn": str,
@@ -107,31 +108,31 @@ CreateEnvironmentMembershipRequestTypeDef = TypedDict(
     },
 )
 
-CreateEnvironmentMembershipResultResponseTypeDef = TypedDict(
-    "CreateEnvironmentMembershipResultResponseTypeDef",
+CreateEnvironmentMembershipResultTypeDef = TypedDict(
+    "CreateEnvironmentMembershipResultTypeDef",
     {
         "membership": "EnvironmentMemberTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-DeleteEnvironmentMembershipRequestTypeDef = TypedDict(
-    "DeleteEnvironmentMembershipRequestTypeDef",
+DeleteEnvironmentMembershipRequestRequestTypeDef = TypedDict(
+    "DeleteEnvironmentMembershipRequestRequestTypeDef",
     {
         "environmentId": str,
         "userArn": str,
     },
 )
 
-DeleteEnvironmentRequestTypeDef = TypedDict(
-    "DeleteEnvironmentRequestTypeDef",
+DeleteEnvironmentRequestRequestTypeDef = TypedDict(
+    "DeleteEnvironmentRequestRequestTypeDef",
     {
         "environmentId": str,
     },
 )
 
-DescribeEnvironmentMembershipsRequestTypeDef = TypedDict(
-    "DescribeEnvironmentMembershipsRequestTypeDef",
+DescribeEnvironmentMembershipsRequestRequestTypeDef = TypedDict(
+    "DescribeEnvironmentMembershipsRequestRequestTypeDef",
     {
         "userArn": str,
         "environmentId": str,
@@ -142,8 +143,8 @@ DescribeEnvironmentMembershipsRequestTypeDef = TypedDict(
     total=False,
 )
 
-DescribeEnvironmentMembershipsResultResponseTypeDef = TypedDict(
-    "DescribeEnvironmentMembershipsResultResponseTypeDef",
+DescribeEnvironmentMembershipsResultTypeDef = TypedDict(
+    "DescribeEnvironmentMembershipsResultTypeDef",
     {
         "memberships": List["EnvironmentMemberTypeDef"],
         "nextToken": str,
@@ -151,15 +152,15 @@ DescribeEnvironmentMembershipsResultResponseTypeDef = TypedDict(
     },
 )
 
-DescribeEnvironmentStatusRequestTypeDef = TypedDict(
-    "DescribeEnvironmentStatusRequestTypeDef",
+DescribeEnvironmentStatusRequestRequestTypeDef = TypedDict(
+    "DescribeEnvironmentStatusRequestRequestTypeDef",
     {
         "environmentId": str,
     },
 )
 
-DescribeEnvironmentStatusResultResponseTypeDef = TypedDict(
-    "DescribeEnvironmentStatusResultResponseTypeDef",
+DescribeEnvironmentStatusResultTypeDef = TypedDict(
+    "DescribeEnvironmentStatusResultTypeDef",
     {
         "status": EnvironmentStatusType,
         "message": str,
@@ -167,15 +168,15 @@ DescribeEnvironmentStatusResultResponseTypeDef = TypedDict(
     },
 )
 
-DescribeEnvironmentsRequestTypeDef = TypedDict(
-    "DescribeEnvironmentsRequestTypeDef",
+DescribeEnvironmentsRequestRequestTypeDef = TypedDict(
+    "DescribeEnvironmentsRequestRequestTypeDef",
     {
         "environmentIds": List[str],
     },
 )
 
-DescribeEnvironmentsResultResponseTypeDef = TypedDict(
-    "DescribeEnvironmentsResultResponseTypeDef",
+DescribeEnvironmentsResultTypeDef = TypedDict(
+    "DescribeEnvironmentsResultTypeDef",
     {
         "environments": List["EnvironmentTypeDef"],
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -242,8 +243,8 @@ class EnvironmentTypeDef(_RequiredEnvironmentTypeDef, _OptionalEnvironmentTypeDe
     pass
 
 
-ListEnvironmentsRequestTypeDef = TypedDict(
-    "ListEnvironmentsRequestTypeDef",
+ListEnvironmentsRequestRequestTypeDef = TypedDict(
+    "ListEnvironmentsRequestRequestTypeDef",
     {
         "nextToken": str,
         "maxResults": int,
@@ -251,8 +252,8 @@ ListEnvironmentsRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListEnvironmentsResultResponseTypeDef = TypedDict(
-    "ListEnvironmentsResultResponseTypeDef",
+ListEnvironmentsResultTypeDef = TypedDict(
+    "ListEnvironmentsResultTypeDef",
     {
         "nextToken": str,
         "environmentIds": List[str],
@@ -260,15 +261,15 @@ ListEnvironmentsResultResponseTypeDef = TypedDict(
     },
 )
 
-ListTagsForResourceRequestTypeDef = TypedDict(
-    "ListTagsForResourceRequestTypeDef",
+ListTagsForResourceRequestRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestRequestTypeDef",
     {
         "ResourceARN": str,
     },
 )
 
-ListTagsForResourceResponseResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseResponseTypeDef",
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
     {
         "Tags": List["TagTypeDef"],
         "ResponseMetadata": "ResponseMetadataTypeDef",
@@ -296,8 +297,8 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-TagResourceRequestTypeDef = TypedDict(
-    "TagResourceRequestTypeDef",
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
     {
         "ResourceARN": str,
         "Tags": List["TagTypeDef"],
@@ -312,16 +313,16 @@ TagTypeDef = TypedDict(
     },
 )
 
-UntagResourceRequestTypeDef = TypedDict(
-    "UntagResourceRequestTypeDef",
+UntagResourceRequestRequestTypeDef = TypedDict(
+    "UntagResourceRequestRequestTypeDef",
     {
         "ResourceARN": str,
         "TagKeys": List[str],
     },
 )
 
-UpdateEnvironmentMembershipRequestTypeDef = TypedDict(
-    "UpdateEnvironmentMembershipRequestTypeDef",
+UpdateEnvironmentMembershipRequestRequestTypeDef = TypedDict(
+    "UpdateEnvironmentMembershipRequestRequestTypeDef",
     {
         "environmentId": str,
         "userArn": str,
@@ -329,22 +330,22 @@ UpdateEnvironmentMembershipRequestTypeDef = TypedDict(
     },
 )
 
-UpdateEnvironmentMembershipResultResponseTypeDef = TypedDict(
-    "UpdateEnvironmentMembershipResultResponseTypeDef",
+UpdateEnvironmentMembershipResultTypeDef = TypedDict(
+    "UpdateEnvironmentMembershipResultTypeDef",
     {
         "membership": "EnvironmentMemberTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-_RequiredUpdateEnvironmentRequestTypeDef = TypedDict(
-    "_RequiredUpdateEnvironmentRequestTypeDef",
+_RequiredUpdateEnvironmentRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateEnvironmentRequestRequestTypeDef",
     {
         "environmentId": str,
     },
 )
-_OptionalUpdateEnvironmentRequestTypeDef = TypedDict(
-    "_OptionalUpdateEnvironmentRequestTypeDef",
+_OptionalUpdateEnvironmentRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateEnvironmentRequestRequestTypeDef",
     {
         "name": str,
         "description": str,
@@ -353,7 +354,7 @@ _OptionalUpdateEnvironmentRequestTypeDef = TypedDict(
 )
 
 
-class UpdateEnvironmentRequestTypeDef(
-    _RequiredUpdateEnvironmentRequestTypeDef, _OptionalUpdateEnvironmentRequestTypeDef
+class UpdateEnvironmentRequestRequestTypeDef(
+    _RequiredUpdateEnvironmentRequestRequestTypeDef, _OptionalUpdateEnvironmentRequestRequestTypeDef
 ):
     pass
